==> fluid_utils-0.1.0.tar.gz: fluid_utils-0.1.0/src/fluid_utils/records/nassco/pipe_materials.py <==
from ...utils.abbreviated_enum import AbbreviatedEnum


class PipeMaterial(AbbreviatedEnum):
    acrylonitrile_butadiene_styrene = ("Acrylonitrile Butadiene Styrene", "ABS")
    asbestos_cement = ("Asbestos Cement", "AC")
    brick = ("Brick", "BR")
    cast_iron = ("Cast Iron", "CAS")
    clay_lined_concrete = ("Clay-Lined Concrete pipe", "CLC")
    corrugated_metal_pipe = ("Corrugated Metal Pipe", "CMP")
    concrete_pipe = ("Concrete Pipe (non-reinforced, usually found in smaller diameters)", "CP")
    concrete_segments_bolted = ("Concrete Segments (bolted)", "CSB")
    concrete_segments_unbolted = ("Concrete Segments (unbolted)", "CSU")
    clay_tile = ("Clay Tile (not vitrified clay)", "CT")
    ductile_iron_pipe = ("Ductile Iron Pipe", "DIP")
    fibreglass_reinforced_pipe = ("Fibreglass Reinforced Pipe", "FRP")
    pitch_fiber_orangeburg = ("Pitch Fiber (Orangeburg, tar-impregnated cardboard)", "OB")
    pre_stressed_concrete_cylinder_pipe = ("Pre-Stressed Concrete Cylinder Pipe", "PCCP")
    polymer_concrete_pipe = ("Polymer Concrete Pipe", "PCP")
    polyethylene = ("Polyethylene", "PE")
    polypropylene = ("Polypropylene", "PP")
    plastic_steel_composite = ("Plastic/Steel Composite", "PSC")
    polyvinyl_chloride = ("Polyvinyl Chloride", "PVC")
    reinforced_concrete_pipe = ("Reinforced Concrete Pipe", "RCP")
    reinforced_plastic_pipe = ("Reinforced Plastic Pipe (truss pipe)", "RMP")
    segmented_block = ("Segmented Block", "SB")
    steel_pipe = ("Steel Pipe", "SP")
    vitrified_clay_pipe = ("Vitrified Clay Pipe", "VCP")
    wood = ("Wood", "WD")
    not_known = ("Not Known", "XXX")
    other = ("Other", "ZZZ")

==> fluid_utils-1.6.6.tar.gz: fluid_utils-1.6.6/src/fluid_utils/records/nassco/pipe_materials.py <==
from ...utils.abbreviated_enum import AbbreviatedEnum


class PipeMaterial(AbbreviatedEnum):
    acrylonitrile_butadiene_styrene = ("Acrylonitrile Butadiene Styrene", "ABS")
    asbestos_cement = ("Asbestos Cement", "AC")
    brick = ("Brick", "BR")
    cast_iron = ("Cast Iron", "CAS")
    clay_lined_concrete = ("Clay-Lined Concrete pipe", "CLC")
    corrugated_metal_pipe = ("Corrugated Metal Pipe", "CMP")
    concrete_pipe = ("Concrete Pipe (non-reinforced)", "CP")
    concrete_segments_bolted = ("Concrete Segments (bolted)", "CSB")
    concrete_segments_unbolted = ("Concrete Segments (unbolted)", "CSU")
    clay_tile = ("Clay Tile (not vitrified clay)", "CT")
    ductile_iron_pipe = ("Ductile Iron Pipe", "DIP")
    fibreglass_reinforced_pipe = ("Fibreglass Reinforced Pipe", "FRP")
    pitch_fiber_orangeburg = ("Pitch Fiber (Orangeburg, tar-impregnated cardboard)", "OB")
    pre_stressed_concrete_cylinder_pipe = ("Pre-Stressed Concrete Cylinder Pipe", "PCCP")
    polymer_concrete_pipe = ("Polymer Concrete Pipe", "PCP")
    polyethylene = ("Polyethylene", "PE")
    polypropylene = ("Polypropylene", "PP")
    plastic_steel_composite = ("Plastic/Steel Composite", "PSC")
    polyvinyl_chloride = ("Polyvinyl Chloride", "PVC")
    reinforced_concrete_pipe = ("Reinforced Concrete Pipe", "RCP")
    reinforced_plastic_pipe = ("Reinforced Plastic Pipe (truss pipe)", "RMP")
    segmented_block = ("Segmented Block", "SB")
    steel_pipe = ("Steel Pipe", "SP")
    vitrified_clay_pipe = ("Vitrified Clay Pipe", "VCP")
    wood = ("Wood", "WD")
    not_known = ("Not Known", "XXX")
    other = ("Other", "ZZZ")
